import distutils.dist

import mock
import pytest
import setuptools.dist

import readme_renderer.integration.distutils


def test_valid_rst():
    dist = distutils.dist.Distribution(attrs=dict(
        long_description="Hello, I am some text."))
    checker = readme_renderer.integration.distutils.Check(dist)
    checker.warn = mock.Mock()

    checker.check_restructuredtext()

    checker.warn.assert_not_called()


def test_invalid_rst():
    dist = distutils.dist.Distribution(attrs=dict(
        long_description="Hello, I am some `totally borked< text."))
    checker = readme_renderer.integration.distutils.Check(dist)
    checker.warn = mock.Mock()
    checker.announce = mock.Mock()

    checker.check_restructuredtext()

    # Should warn once for the syntax error, and finally to warn that the
    # overall syntax is invalid
    checker.warn.assert_called_once_with(mock.ANY)
    message = checker.warn.call_args[0][0]
    assert 'invalid markup' in message
    assert 'line 1: Warning:' in message
    assert 'start-string without end-string' in message

    # Should not have announced that it was valid.
    checker.announce.assert_not_called()


def test_malicious_rst():
    description = """
.. raw:: html
    <script>I am evil</script>
"""
    dist = distutils.dist.Distribution(attrs=dict(
        long_description=description))
    checker = readme_renderer.integration.distutils.Check(dist)
    checker.warn = mock.Mock()
    checker.announce = mock.Mock()

    checker.check_restructuredtext()

    # Should warn once for the syntax error, and finally to warn that the
    # overall syntax is invalid
    checker.warn.assert_called_once_with(mock.ANY)
    message = checker.warn.call_args[0][0]
    assert 'directive disabled' in message

    # Should not have announced that it was valid.
    checker.announce.assert_not_called()


@pytest.mark.filterwarnings('ignore:::distutils.dist')
def test_markdown():
    dist = setuptools.dist.Distribution(attrs=dict(
        long_description="Hello, I am some text.",
        long_description_content_type="text/markdown"))
    checker = readme_renderer.integration.distutils.Check(dist)
    checker.warn = mock.Mock()

    checker.check_restructuredtext()

    checker.warn.assert_called()
    assert 'content type' in checker.warn.call_args[0][0]


def test_invalid_missing():
    dist = distutils.dist.Distribution(attrs=dict())
    checker = readme_renderer.integration.distutils.Check(dist)
    checker.warn = mock.Mock()

    checker.check_restructuredtext()

    checker.warn.assert_called_once_with(mock.ANY)
    assert 'missing' in checker.warn.call_args[0][0]


def test_invalid_empty():
    dist = distutils.dist.Distribution(attrs=dict(
        long_description=""))
    checker = readme_renderer.integration.distutils.Check(dist)
    checker.warn = mock.Mock()

    checker.check_restructuredtext()

    checker.warn.assert_called_once_with(mock.ANY)
    assert 'missing' in checker.warn.call_args[0][0]



import io
import glob
import os.path

import pytest

from readme_renderer.txt import render


@pytest.mark.parametrize(
    ("txt_filename", "html_filename"),
    [
        (fn, os.path.splitext(fn)[0] + ".html")
        for fn in glob.glob(
            os.path.join(os.path.dirname(__file__), "fixtures", "test_*.txt")
        )
    ],
)
def test_txt_fixtures(txt_filename, html_filename):
    # Get our Markup
    with io.open(txt_filename, encoding='utf-8') as f:
        txt_markup = f.read()

    # Get our expected
    with io.open(html_filename, encoding="utf-8") as f:
        expected = f.read()

    out = render(txt_markup)

    assert out.strip() == expected.strip()



# Copyright 2014 Donald Stufft
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
from __future__ import absolute_import, division, print_function

import os

import setuptools

base_dir = os.path.dirname(__file__)

with open(os.path.join(base_dir, "readme_renderer", "__about__.py")) as f:
    about = {}
    exec(f.read(), about)

with open(os.path.join(base_dir, "README.rst")) as f:
    long_description = f.read()


setuptools.setup(
    name=about["__title__"],
    version=about["__version__"],

    description=about["__summary__"],
    long_description=long_description,
    license=about["__license__"],
    url=about["__uri__"],

    author=about["__author__"],
    author_email=about["__email__"],

    classifiers=[
        "Intended Audience :: Developers",
        "License :: OSI Approved :: Apache Software License",
        "Natural Language :: English",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: POSIX",
        "Operating System :: POSIX :: BSD",
        "Operating System :: POSIX :: Linux",
        "Operating System :: Microsoft :: Windows",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: Implementation :: CPython",
        "Programming Language :: Python :: Implementation :: PyPy",
    ],

    install_requires=[
        "bleach>=2.1.0",
        "docutils>=0.13.1",
        "Pygments",
        "six",
    ],

    entry_points={
        "distutils.commands": [
            "check = readme_renderer.integration.distutils:Check",
        ],
    },

    extras_require={
        "md": "cmarkgfm>=0.2.0",
    },

    packages=setuptools.find_packages(exclude=["tests", "tests.*"]),
)
